package test_entitlements_ui;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.actions.ActionFactory;
import org.eclipse.ui.actions.ActionFactory.IWorkbenchAction;
import org.eclipse.ui.application.ActionBarAdvisor;
import org.eclipse.ui.application.IActionBarConfigurer;


/**
 * An action bar advisor is responsible for creating, adding, and disposing of
 * the actions added to a workbench window. Each window will be populated with
 * new actions.
 */
public class ApplicationActionBarAdvisor extends ActionBarAdvisor {

	// --- members ---
	
	protected Shell fShell;
	protected IAction fConnectAction;
	protected IWorkbenchAction exitAction;
	
	
	// --- constructors ---

	public ApplicationActionBarAdvisor(IActionBarConfigurer configurer) {
		super(configurer);
	}
	
	
	// --- methods ---

	protected void makeActions(final IWorkbenchWindow window) {
		fShell = window.getShell();
		
		// Creates the actions and registers them.
		// Registering is needed to ensure that key bindings work.
		// The corresponding commands keybindings are defined in the plugin.xml file.
		// Registering also provides automatic disposal of the actions when
		// the window is closed.
		
		fConnectAction = new Action ("Connect") {
			@Override
			public void run() {
				TestEntitlementsUIPlugin.getDefault().connect ("sb://localhost/", fShell);
			}
		};
		
		// Connect now:
		fConnectAction.run();

		exitAction = ActionFactory.QUIT.create(window);
		register(exitAction);
	}

	protected void fillMenuBar(IMenuManager menuBar) {
		MenuManager fileMenu = new MenuManager("&File", IWorkbenchActionConstants.M_FILE);
		menuBar.add (fileMenu);
		fileMenu.add (fConnectAction);
		fileMenu.add (new Separator());
		fileMenu.add (exitAction);
	}
}
